==> haskell-asn1-types-0.3.2-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.2
id: asn1-types-0.3.2-JTXhhGhoZcYFVVTnQkvDfL
key: asn1-types-0.3.2-JTXhhGhoZcYFVVTnQkvDfL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1-types
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
abi: ab78b66ed9b6dedc90b480e2a4d5bb49
exposed: True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-types-0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-types-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/asn1-types-0.3.2
hs-libraries: HSasn1-types-0.3.2-JTXhhGhoZcYFVVTnQkvDfL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    hourglass-0.2.11-HZDf9BC3ncm8KHsGKeZrlx
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             hourglass-0.2.11-HZDf9BC3ncm8KHsGKeZrlx=220e1dc4fc12d70cda3b2ca65c2641ac
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.2-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.2
id: asn1-types-0.3.2-H6zXkdeVhjq7CWaqL2pyQz
key: asn1-types-0.3.2-H6zXkdeVhjq7CWaqL2pyQz
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1-types
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
abi: 935ae5099a27537f289d605feb755c51
exposed: True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-types-0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-types-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/asn1-types-0.3.2
hs-libraries: HSasn1-types-0.3.2-H6zXkdeVhjq7CWaqL2pyQz
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    hourglass-0.2.11-pmYJsDA77TGYbwvqkTGv1
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             hourglass-0.2.11-pmYJsDA77TGYbwvqkTGv1=78fd717616725a597d3d91ed5a9d940d
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
